- Collector for: https://github.com/Blueliv/api-python-sdk
- Needs this prerequisite: ```pip install git+git://github.com/Blueliv/api-python-sdk```
- The runtime.conf parameter "api_key", register here: https://map.blueliv.com/?redirect=get-started#signup


